@@ -4,9 +4,7 @@ import spacy
 from termcolor import colored
 import regex as re
 from itertools import chain 
-from tqdm import tqdm
-import tqdm.notebook as tq
-import os, sys, gc
+import os, sys
 
 
 try: 
@@ -28,7 +26,7 @@ class PassivePyAnalyzer:
             save the output to a file
 
         """
-        def __init__(self, spacy_model = "en_core_web_lg"):
+        def __init__(self, nlp:spacy.language.Language=None, spacy_model:str = "en_core_web_lg"):
 
             """
             Create the Detector
@@ -39,9 +37,7 @@ class PassivePyAnalyzer:
             
             
             """
-            # os.system('pip install -r https://raw.githubusercontent.com/mitramir55/PassivePy/main/PassivePyCode/PassivePySrc/requirements.txt')
-            
-            self.nlp, self.matcher = create_matcher(spacy_model)
+            self.nlp, self.matcher = create_matcher(nlp=nlp, spacy_model=spacy_model)
             self.matcher_t = create_matcher_truncated(self.nlp)
             self.matcher_f = create_matcher_full(self.nlp)
 
@@ -362,7 +358,7 @@ class PassivePyAnalyzer:
         def match_sentence_level(self, df, column_name, n_process = 1,
                                 batch_size = 1000, add_other_columns=True,
                                 truncated_passive=False, full_passive=False):
-
+                                
             """
             Parameters
 
@@ -400,16 +396,14 @@ class PassivePyAnalyzer:
 
 
             # concatenating the results with the initial df -------------------
+            if len(df.columns) == 1: 
+                add_other_columns=False
             if add_other_columns:
 
                 other_cols_df = self._add_other_cols(df, column_name, count_sents)
                 assert len(other_cols_df) == len(df_output)
-                df_final = pd.concat([df_output, other_cols_df], axis = 1)
-
-                return df_final
-
-            else:
-                return df_output
+                df_output = pd.concat([df_output, other_cols_df], axis = 1)
+            return df_output
 
 
         def _all_elements_in_one_list(self, series_: pd.Series(list)) -> list:
@@ -569,6 +563,9 @@ class PassivePyAnalyzer:
             df_output = pd.DataFrame(output_dict)
                
             # add other columns in the initial df -------------------------------------------
+            if len(df.columns) == 1: 
+                add_other_columns=False
+
             if add_other_columns:
                 
                 # create a list of all the col names
@@ -578,12 +575,10 @@ class PassivePyAnalyzer:
                 del fields[fields.index(column_name)]
 
                 assert len(df[fields]) == len(df_output)
-
                 df_output = pd.concat([df_output, df[fields]], axis = 1)
             
             return df_output
 
-
 # for stopping the print statements in one sample sentences
 class HiddenPrints:
     def __enter__(self):
